@@ -5,65 +5,34 @@ var Enumerations_8H =
     [ "FL_Alt_L", "Enumerations_8H.html#a94997ca62280cddce9327c32a256b61a", null ],
     [ "FL_Alt_R", "Enumerations_8H.html#aa06e5417c1a4f46e591950c1a2c28301", null ],
     [ "FL_API_VERSION", "Enumerations_8H.html#a53186dc2831a9786ba70657c771871a7", null ],
-    [ "FL_Back", "Enumerations_8H.html#a4d84842f7c280df258fd0fb8bad02e98", null ],
+    [ "FL_BACK_MOUSE", "Enumerations_8H.html#ac88d21e0a4c27595ab6a8dbfa149afdd", null ],
     [ "FL_BackSpace", "Enumerations_8H.html#a20dc86e7758a88b4d1f06323e2de9896", null ],
-    [ "FL_Button", "Enumerations_8H.html#a1df1e46a5113628156ed7b7f995217d0", null ],
     [ "FL_BUTTON", "Enumerations_8H.html#a9c1d8f71cc0a6c159eac4f250ead7687", null ],
+    [ "FL_Button", "Enumerations_8H.html#a1df1e46a5113628156ed7b7f995217d0", null ],
     [ "FL_BUTTON1", "Enumerations_8H.html#afe37a4db5e516754bb8963cd341bf415", null ],
     [ "FL_BUTTON2", "Enumerations_8H.html#a1b597a61f3be6323bce3e8c54283b2b3", null ],
     [ "FL_BUTTON3", "Enumerations_8H.html#a9609bc7247660e05194c4e639f84e24e", null ],
+    [ "FL_BUTTON4", "Enumerations_8H.html#ac73b2f46df79e0b2421d291c98a226e3", null ],
+    [ "FL_BUTTON5", "Enumerations_8H.html#a94f6ac28c07319c6b7b5c7f6be41843d", null ],
     [ "FL_BUTTONS", "Enumerations_8H.html#a6862e0de33aa388ec19a5e0cf3327bb7", null ],
-    [ "FL_Caps_Lock", "Enumerations_8H.html#a55c0fc2c4fdd81b243e9036b536484e3", null ],
     [ "FL_CAPS_LOCK", "Enumerations_8H.html#add5e55eea768b7bbc0cd25a2455811f0", null ],
-    [ "FL_CIRCLE_BOX", "Enumerations_8H.html#ad6bb5f706979ab969b7d3abafabc3be8", null ],
-    [ "FL_COLOR_CUBE", "Enumerations_8H.html#aa7c78133d1b30447471ac02feb40c553", null ],
+    [ "FL_Caps_Lock", "Enumerations_8H.html#a55c0fc2c4fdd81b243e9036b536484e3", null ],
     [ "FL_COMMAND", "Enumerations_8H.html#a5d4011c75b1fe25d9ef36e8ae9e2995c", null ],
     [ "FL_CONTROL", "Enumerations_8H.html#a25fe41b1bd340d52f7970051d8b680bc", null ],
     [ "FL_Control_L", "Enumerations_8H.html#adefca9b73c422d3dadf3fa555d1fb913", null ],
     [ "FL_Control_R", "Enumerations_8H.html#aecba53654154e1c0b22351106636ea79", null ],
     [ "FL_CTRL", "Enumerations_8H.html#a29324ec5ac8c1d87950127d387dc83e8", null ],
     [ "FL_Delete", "Enumerations_8H.html#a323fcf5bab321ec05826a6510a0f1d5a", null ],
-    [ "FL_DIAMOND_BOX", "Enumerations_8H.html#ad1e7bda8ee54a4a67772fcd004e07d76", null ],
-    [ "FL_DIAMOND_DOWN_BOX", "Enumerations_8H.html#a35f4e640a841d9ac769e4e916f57c79e", null ],
-    [ "FL_DIAMOND_UP_BOX", "Enumerations_8H.html#a373a1c80f6eca4b7cb87fb311926755b", null ],
     [ "FL_Down", "Enumerations_8H.html#a7b70dabd5fc84d90552442584a0e8b91", null ],
     [ "FL_Eisu", "Enumerations_8H.html#a3c7fc1e50954da94b6d5d2bad4ab3090", null ],
-    [ "FL_EMBOSSED_LABEL", "Enumerations_8H.html#aa8215ff52c3386f676ac92d55bf57c18", null ],
     [ "FL_End", "Enumerations_8H.html#a3278d6209799b821e07369aa5dc140ac", null ],
-    [ "FL_ENGRAVED_LABEL", "Enumerations_8H.html#a2f03450b19c29126ec202b3505023b7b", null ],
     [ "FL_Enter", "Enumerations_8H.html#ab4a527fe4d93303976de2fbfec05e19b", null ],
     [ "FL_Escape", "Enumerations_8H.html#a91b983ebe4cd86393e2addb8ab40a326", null ],
     [ "FL_F", "Enumerations_8H.html#ae793aa65307884c2ad99893508d844f2", null ],
     [ "FL_F_Last", "Enumerations_8H.html#a104d0fea5c26197d28294d319dd93af3", null ],
-    [ "FL_Favorites", "Enumerations_8H.html#ad363513e10d9b636ffd7bd3e336edd3a", null ],
-    [ "FL_Forward", "Enumerations_8H.html#a48da3f51baf7f6c3c7cc8991b3db822c", null ],
-    [ "FL_FRAME", "Enumerations_8H.html#a17efe847a8cb25574f629cb5c761c94e", null ],
-    [ "FL_FRAME_BOX", "Enumerations_8H.html#a7024b601032a8da947f10b618896cfca", null ],
-    [ "FL_FREE_COLOR", "Enumerations_8H.html#aa8fe2e5047a2dd1be37e8336dfca918d", null ],
-    [ "FL_GLEAM_DOWN_BOX", "Enumerations_8H.html#a1feae67fdcd776ea39d3264c28712430", null ],
-    [ "FL_GLEAM_DOWN_FRAME", "Enumerations_8H.html#ae467bf27a6946e7598ecd88f294d2efd", null ],
-    [ "FL_GLEAM_ROUND_DOWN_BOX", "Enumerations_8H.html#add90f42e02947c4be12409786bda2789", null ],
-    [ "FL_GLEAM_ROUND_UP_BOX", "Enumerations_8H.html#a06897dd7e14889699ea8ca6b75755385", null ],
-    [ "FL_GLEAM_THIN_DOWN_BOX", "Enumerations_8H.html#a18648039f4badc3bab9f97d144a5ce40", null ],
-    [ "FL_GLEAM_THIN_UP_BOX", "Enumerations_8H.html#aefc2da5a8c9009700dcfd638561e6aac", null ],
-    [ "FL_GLEAM_UP_BOX", "Enumerations_8H.html#a1c287900089242eda925b8b793c078a4", null ],
-    [ "FL_GLEAM_UP_FRAME", "Enumerations_8H.html#acd1bf412b2ad37448c3f616a0fdf5e34", null ],
-    [ "FL_GRAY", "Enumerations_8H.html#aabb3b3628ea5baa2ba176201ed5d2aba", null ],
-    [ "FL_GRAY_RAMP", "Enumerations_8H.html#ad6657159174ebe4d3b6f1b3e777e98c9", null ],
-    [ "FL_GTK_DOWN_BOX", "Enumerations_8H.html#a3a528a8f0c33e1fb67e36204d1f73400", null ],
-    [ "FL_GTK_DOWN_FRAME", "Enumerations_8H.html#a750366c4bc1f27fe04af93e4e715bf82", null ],
-    [ "FL_GTK_ROUND_DOWN_BOX", "Enumerations_8H.html#a2d0efd51e202f009819dcd5eb6113d94", null ],
-    [ "FL_GTK_ROUND_UP_BOX", "Enumerations_8H.html#a618a600f1b9483078485a15a4222dcb8", null ],
-    [ "FL_GTK_THIN_DOWN_BOX", "Enumerations_8H.html#ade14a87733635b6adec1ad50aa3b83fd", null ],
-    [ "FL_GTK_THIN_DOWN_FRAME", "Enumerations_8H.html#a29d0c81589c9ab30d5e6a4b2737c5a47", null ],
-    [ "FL_GTK_THIN_UP_BOX", "Enumerations_8H.html#af993169ad2ca66074e91f3b8bda7f2f8", null ],
-    [ "FL_GTK_THIN_UP_FRAME", "Enumerations_8H.html#a4340208bda56659fae8c7fdcbf32c244", null ],
-    [ "FL_GTK_UP_BOX", "Enumerations_8H.html#a3a2557d7c3ab38846e738284a6e8a2ff", null ],
-    [ "FL_GTK_UP_FRAME", "Enumerations_8H.html#a017e1bfd1fbdbb8da13f92f9ff14cb24", null ],
+    [ "FL_FORWARD_MOUSE", "Enumerations_8H.html#a2b33ea1af3fd52f316ca4cdc1ab125e7", null ],
     [ "FL_Help", "Enumerations_8H.html#aea65b2b57d3d83d1359df6fc538ff0a9", null ],
     [ "FL_Home", "Enumerations_8H.html#a6fecadc9ecc21f06822c79ced2e45932", null ],
-    [ "FL_Home_Page", "Enumerations_8H.html#a6f8bd6f6a981fcd248499fe474290c30", null ],
-    [ "FL_IMAGE_WITH_ALPHA", "Enumerations_8H.html#a75fbead6c57b832581fb339b5f193e16", null ],
     [ "FL_Insert", "Enumerations_8H.html#ae18bfb47b2b5d5579d227d522a3ce32c", null ],
     [ "FL_Iso_Key", "Enumerations_8H.html#ae56945dcc3ab2a95c59b32ab54bcaabd", null ],
     [ "FL_JIS_Underscore", "Enumerations_8H.html#aef1720c9124147c2aea2b647089b2518", null ],
@@ -74,71 +43,32 @@ var Enumerations_8H =
     [ "FL_KP_Last", "Enumerations_8H.html#a14fb705c31fdb8357ae4f3718e20a018", null ],
     [ "FL_Left", "Enumerations_8H.html#afe89caa1c5019809095a6129156f7c5a", null ],
     [ "FL_LEFT_MOUSE", "Enumerations_8H.html#a33b6ebe3faf691660603b03bf4bbeeb8", null ],
-    [ "FL_Mail", "Enumerations_8H.html#a210eaddbc06c881344b2a1f3f96c33c9", null ],
     [ "FL_MAJOR_VERSION", "Enumerations_8H.html#a10c923db4d613150c8a3937f9775ccd0", null ],
-    [ "FL_Media_Next", "Enumerations_8H.html#a08a4c02d77576954b914b4708d8a8ecb", null ],
-    [ "FL_Media_Play", "Enumerations_8H.html#ad835d80c11553c5910cbf57f17ff77b6", null ],
-    [ "FL_Media_Prev", "Enumerations_8H.html#a1e8fb91e68eb70283b4f76afca3529fb", null ],
-    [ "FL_Media_Stop", "Enumerations_8H.html#a313d081817e6499ae861f95d8c138b0c", null ],
     [ "FL_Menu", "Enumerations_8H.html#a3a59855ebd5a902cda138956b5ac80bb", null ],
     [ "FL_META", "Enumerations_8H.html#a2c50b1b00111f992d5d49f07c9cee22a", null ],
     [ "FL_Meta_L", "Enumerations_8H.html#acbd392478a5e61f341fe44e24890e213", null ],
     [ "FL_Meta_R", "Enumerations_8H.html#aa21f26e0bc5b3737cf8c0a1b89a200be", null ],
     [ "FL_MIDDLE_MOUSE", "Enumerations_8H.html#a88d6920f2af6a9c2b48be02e5270d097", null ],
     [ "FL_MINOR_VERSION", "Enumerations_8H.html#a165d2781eff3186354a5f5db0528976d", null ],
-    [ "FL_NUM_BLUE", "Enumerations_8H.html#a35ff0c922707d57042cd509c88f88fea", null ],
-    [ "FL_NUM_FREE_COLOR", "Enumerations_8H.html#a4bdca88def38f2e216377f69ea530954", null ],
-    [ "FL_NUM_GRAY", "Enumerations_8H.html#a389c78c6cb1615efe55dfc06b935ec10", null ],
-    [ "FL_NUM_GREEN", "Enumerations_8H.html#aff583e05dea4ac7ec09c3f1760a503c0", null ],
-    [ "FL_Num_Lock", "Enumerations_8H.html#acf1721eb766274a915bed57acf0e7636", null ],
     [ "FL_NUM_LOCK", "Enumerations_8H.html#af4708895fdb16d3982408fee68ba502b", null ],
-    [ "FL_NUM_RED", "Enumerations_8H.html#a696105c253ebbfd89d9dfc37357ed728", null ],
-    [ "FL_OFLAT_BOX", "Enumerations_8H.html#a250fe849afe4a72cebd9b58702aaac50", null ],
-    [ "FL_OSHADOW_BOX", "Enumerations_8H.html#a38d2dcb555947ca32ac6facff8b4bc27", null ],
-    [ "FL_OVAL_BOX", "Enumerations_8H.html#a0d921d8861d182c6f6f696f9db1113e9", null ],
-    [ "FL_OVAL_FRAME", "Enumerations_8H.html#a5e7d5d8837a106f25884e970d359194c", null ],
+    [ "FL_Num_Lock", "Enumerations_8H.html#acf1721eb766274a915bed57acf0e7636", null ],
     [ "FL_Page_Down", "Enumerations_8H.html#ada4d587d21ab710f44043dafba88e110", null ],
     [ "FL_Page_Up", "Enumerations_8H.html#a35834a5c204afffb06374e25734b5c76", null ],
     [ "FL_PATCH_VERSION", "Enumerations_8H.html#afc7b82e6fcfbb451d38e8a0cacde302a", null ],
     [ "FL_Pause", "Enumerations_8H.html#a701e11753a0c38777cb49989de8f0195", null ],
-    [ "FL_PLASTIC_DOWN_BOX", "Enumerations_8H.html#a07239e54973afe65305b4d72f9546ad6", null ],
-    [ "FL_PLASTIC_DOWN_FRAME", "Enumerations_8H.html#a7c5319d276f2b9393f25b528c7f4e42e", null ],
-    [ "FL_PLASTIC_ROUND_DOWN_BOX", "Enumerations_8H.html#a261020ee5b7f94f75a2d667c68521d78", null ],
-    [ "FL_PLASTIC_ROUND_UP_BOX", "Enumerations_8H.html#ad86ffc9d6fa9cc818a1e424c95e12d37", null ],
-    [ "FL_PLASTIC_THIN_DOWN_BOX", "Enumerations_8H.html#a29922eec41811761eda1670cc44ca569", null ],
-    [ "FL_PLASTIC_THIN_UP_BOX", "Enumerations_8H.html#a3650aaf6d19724ef602101edf534268a", null ],
-    [ "FL_PLASTIC_UP_BOX", "Enumerations_8H.html#a8712c687538f7d4966c0461c3d913b5f", null ],
-    [ "FL_PLASTIC_UP_FRAME", "Enumerations_8H.html#a1deb4a0b0cdff790242a812f137c61e0", null ],
     [ "FL_Print", "Enumerations_8H.html#a4b01dd00e8057590d3778a41920cf80f", null ],
-    [ "FL_Refresh", "Enumerations_8H.html#a11f38eb030e2b705568f3ab0f1afa19b", null ],
-    [ "FL_RFLAT_BOX", "Enumerations_8H.html#a4a3f9e7a782892ca79eec39a02c704b4", null ],
     [ "FL_Right", "Enumerations_8H.html#a45679ed656e6b248319719719e894f13", null ],
     [ "FL_RIGHT_MOUSE", "Enumerations_8H.html#ace3b88a65f6aabab96b0bcc411470c77", null ],
-    [ "FL_ROUND_DOWN_BOX", "Enumerations_8H.html#a792a19a6999cf43f93a7895e891d40a9", null ],
-    [ "FL_ROUND_UP_BOX", "Enumerations_8H.html#a7d2ffbfc7801c6f04562fc18e53b9cd4", null ],
-    [ "FL_ROUNDED_BOX", "Enumerations_8H.html#a3e3a24199c0758ee1d9f25ca2338d692", null ],
-    [ "FL_ROUNDED_FRAME", "Enumerations_8H.html#a26c5f8f256d97c5c9021632cd5d60e15", null ],
-    [ "FL_RSHADOW_BOX", "Enumerations_8H.html#ad14eab3302b2d306b87e61e3bc93f127", null ],
-    [ "FL_Scroll_Lock", "Enumerations_8H.html#a75315b814f32abe29e7b8d0c43be54d9", null ],
     [ "FL_SCROLL_LOCK", "Enumerations_8H.html#aca94eaafd01b36904a24522c2b2a320a", null ],
-    [ "FL_Search", "Enumerations_8H.html#a34ab838e1b43b0f3032fd8949a9cdc97", null ],
-    [ "FL_SHADOW_BOX", "Enumerations_8H.html#a04c0c06aa87ee590f047f51b1980684c", null ],
-    [ "FL_SHADOW_FRAME", "Enumerations_8H.html#acdb464805f3c45206da72d1b33796c91", null ],
-    [ "FL_SHADOW_LABEL", "Enumerations_8H.html#ab44620a0effd74a4ace6244e6e6bb2ee", null ],
+    [ "FL_Scroll_Lock", "Enumerations_8H.html#a75315b814f32abe29e7b8d0c43be54d9", null ],
     [ "FL_SHIFT", "Enumerations_8H.html#aa0d93ca1bc8a0c7f84888cdf458f043d", null ],
     [ "FL_Shift_L", "Enumerations_8H.html#ab81acb8d22583da65645c45cb2da1bed", null ],
     [ "FL_Shift_R", "Enumerations_8H.html#a223901295f3b3157bd082a772f20da77", null ],
-    [ "FL_Sleep", "Enumerations_8H.html#aa11756b6ae4da20e6537da2ce84c385a", null ],
-    [ "FL_Stop", "Enumerations_8H.html#ae71aa5f48130c62ab9f4162ebaf3702d", null ],
     [ "FL_SYMBOL_LABEL", "Enumerations_8H.html#a0f3c67869158635bd9bfe3f97a87fc0e", null ],
     [ "FL_Tab", "Enumerations_8H.html#aa6e3e7f377cecb30c77f112ce54c3753", null ],
     [ "FL_Up", "Enumerations_8H.html#a050700391ba0940ca16b0e5dbf4644f0", null ],
     [ "FL_VERSION", "Enumerations_8H.html#a94499c96b5f3ca212d90a2c41f947a67", null ],
-    [ "FL_Volume_Down", "Enumerations_8H.html#afadeff33bd3f7cd13e7248e2f8f2f4a8", null ],
-    [ "FL_Volume_Mute", "Enumerations_8H.html#a65066ef24e1bb1348f59380bf62e44f7", null ],
-    [ "FL_Volume_Up", "Enumerations_8H.html#a264d7dd0a1a51ac40966c55002d6d7f6", null ],
     [ "FL_Yen", "Enumerations_8H.html#ac6cd51105d96ffad3571677b0d285770", null ],
-    [ "FLTK_ABI_VERSION", "Enumerations_8H.html#a361f72867b226d7eda7267dbc783fc2d", null ],
     [ "Fl_Align", "Enumerations_8H.html#a44e8bcd1e030e65e4f88cbae64a7c3e3", null ],
     [ "Fl_Color", "Enumerations_8H.html#a8b762953646f8abee866061f1af78a6a", null ],
     [ "Fl_Font", "Enumerations_8H.html#a2ac46d9f082834b969fffe490a03a709", null ],
@@ -305,19 +235,6 @@ var Enumerations_8H =
     [ "fl_color_cube", "Enumerations_8H.html#a2f613709d1c9444f9f03e7c0349223f3", null ],
     [ "fl_contrast", "group__fl__attributes.html#ga54d75920c0484916cd6b2101937ec5ff", null ],
     [ "fl_darker", "Enumerations_8H.html#a88fd2733842cb5d287650bcf160f2531", null ],
-    [ "fl_define_FL_DIAMOND_BOX", "Enumerations_8H.html#a137c1cb224a3e3aecb91608a1567e915", null ],
-    [ "fl_define_FL_EMBOSSED_LABEL", "Enumerations_8H.html#a323a068ca36b789472bfb8e50e155b93", null ],
-    [ "fl_define_FL_ENGRAVED_LABEL", "Enumerations_8H.html#ad2356471e464dcdc818929365be0781e", null ],
-    [ "fl_define_FL_GLEAM_UP_BOX", "Enumerations_8H.html#a85391cadfdf4d449af50dc66d2d3c1af", null ],
-    [ "fl_define_FL_GTK_UP_BOX", "Enumerations_8H.html#acddcd32d55f441d62bee63ce326d5f2c", null ],
-    [ "fl_define_FL_OVAL_BOX", "Enumerations_8H.html#a36d20b2fd40d9665512ee16fe89670db", null ],
-    [ "fl_define_FL_PLASTIC_UP_BOX", "Enumerations_8H.html#a5789d998f2b5e51e11e386fcbbe7bbb2", null ],
-    [ "fl_define_FL_RFLAT_BOX", "Enumerations_8H.html#a6f64fe52f3ed86bde407c67a61f5a2a4", null ],
-    [ "fl_define_FL_ROUND_UP_BOX", "Enumerations_8H.html#a10a70f87f0e34937ae479b07fa9cfbf0", null ],
-    [ "fl_define_FL_ROUNDED_BOX", "Enumerations_8H.html#a5830cccb7640d9fb61c1067200b4b9d2", null ],
-    [ "fl_define_FL_RSHADOW_BOX", "Enumerations_8H.html#a7c68477f8da9f5fc9af0b1d0e20d79a3", null ],
-    [ "fl_define_FL_SHADOW_BOX", "Enumerations_8H.html#a4bb54e3e06e377e803dc913d4d61630a", null ],
-    [ "fl_define_FL_SHADOW_LABEL", "Enumerations_8H.html#acceca4e5fa60fae68ee0098bd9f44124", null ],
     [ "fl_down", "Enumerations_8H.html#a6aa37e8d5c59e2e4f40848f9b2b93a70", null ],
     [ "fl_frame", "Enumerations_8H.html#a06e61a87a8570f7debc751a1e2f5340f", null ],
     [ "fl_gray_ramp", "Enumerations_8H.html#a6045423248a367d4d3885109f18e0bd9", null ],
@@ -326,65 +243,34 @@ var Enumerations_8H =
     [ "fl_rgb_color", "Enumerations_8H.html#af26a6486e65decd723fbe5c1f43deb0b", null ],
     [ "fl_rgb_color", "Enumerations_8H.html#a7c5acc4633fbab7016bce2fb69046494", null ],
     [ "FL_ALIGN_BOTTOM", "Enumerations_8H.html#a1ea3fa817f07b80dced581f58de842ae", null ],
-    [ "FL_ALIGN_BOTTOM_LEFT", "Enumerations_8H.html#ac99f378b578558c16fa41c7023b53d55", null ],
-    [ "FL_ALIGN_BOTTOM_RIGHT", "Enumerations_8H.html#ad5c91c4f8b87d48ba1a1120d726bca87", null ],
     [ "FL_ALIGN_CENTER", "Enumerations_8H.html#a427f1ce53c37478a59f64bec4a2e2241", null ],
     [ "FL_ALIGN_CLIP", "Enumerations_8H.html#a527e2db976be1a8508c226b4ca54eaa7", null ],
     [ "FL_ALIGN_IMAGE_BACKDROP", "Enumerations_8H.html#a1aaa3dafad6349ff2e36c2b94694ddc4", null ],
-    [ "FL_ALIGN_IMAGE_MASK", "Enumerations_8H.html#af50ce650b88c5fc3e3fd0ef02f99fb76", null ],
     [ "FL_ALIGN_IMAGE_NEXT_TO_TEXT", "Enumerations_8H.html#ae01274c851cadd0ae5f7c5b519f0245a", null ],
     [ "FL_ALIGN_IMAGE_OVER_TEXT", "Enumerations_8H.html#a44f5822e9594733418ec39f7c061d2d7", null ],
     [ "FL_ALIGN_INSIDE", "Enumerations_8H.html#ade440c90fc9c2495fdf04c9cb34fba34", null ],
     [ "FL_ALIGN_LEFT", "Enumerations_8H.html#aee67f09771b16bc5da1f1ee860681be5", null ],
-    [ "FL_ALIGN_LEFT_BOTTOM", "Enumerations_8H.html#a1ec807dbbb67f9967f6c28170e1d76d8", null ],
-    [ "FL_ALIGN_LEFT_TOP", "Enumerations_8H.html#ad4b4d82940cf211c16057ab7424a1f15", null ],
-    [ "FL_ALIGN_NOWRAP", "Enumerations_8H.html#a701d6772556fa35f072a6d661655c27c", null ],
-    [ "FL_ALIGN_POSITION_MASK", "Enumerations_8H.html#adf741c89d6b1599ac9813aa16d8730f5", null ],
     [ "FL_ALIGN_RIGHT", "Enumerations_8H.html#a16646615fa4863fae6f7975b36c3987e", null ],
-    [ "FL_ALIGN_RIGHT_BOTTOM", "Enumerations_8H.html#a2da73b94e785bf9b0306ea5156f8fd04", null ],
-    [ "FL_ALIGN_RIGHT_TOP", "Enumerations_8H.html#aab3b54d51a61ad3964e483c838bb78fc", null ],
     [ "FL_ALIGN_TEXT_NEXT_TO_IMAGE", "Enumerations_8H.html#a6500fc80f0febfd4bd87025a3df5cff6", null ],
     [ "FL_ALIGN_TEXT_OVER_IMAGE", "Enumerations_8H.html#ab6413c20d509320c27f498ef2d65ce3f", null ],
     [ "FL_ALIGN_TOP", "Enumerations_8H.html#a62b22e4022b39d90a2d3962ae144f2e8", null ],
-    [ "FL_ALIGN_TOP_LEFT", "Enumerations_8H.html#aa8fc090c53e2f726bd4817189313a0da", null ],
-    [ "FL_ALIGN_TOP_RIGHT", "Enumerations_8H.html#a2994f88481b359b5bbcce9de598150fd", null ],
     [ "FL_ALIGN_WRAP", "Enumerations_8H.html#ad824439377f8aa436e39c5d12d9fb26f", null ],
     [ "FL_BACKGROUND2_COLOR", "Enumerations_8H.html#a5c5704ed2ec5eb9c964d6dcb51474055", null ],
-    [ "FL_BACKGROUND_COLOR", "Enumerations_8H.html#aa1c7250c485966fcd5c49f1bdc3a6587", null ],
-    [ "FL_BLACK", "Enumerations_8H.html#a705ea07a3ad2b7e3b7745c9c3c651bba", null ],
-    [ "FL_BLUE", "Enumerations_8H.html#a9fab9562bef18bcf13f1b827b38a4ba9", null ],
     [ "FL_BOLD", "Enumerations_8H.html#a5b4c5d04c411d4c086101f5b955c556a", null ],
     [ "FL_BOLD_ITALIC", "Enumerations_8H.html#a45f68cc36d155e45c4bea90a486a5e13", null ],
     [ "FL_COURIER", "Enumerations_8H.html#ae722fe030bd9bcba33f045098295579d", null ],
     [ "FL_COURIER_BOLD", "Enumerations_8H.html#a311479135f085f16d2a7432af8f482eb", null ],
     [ "FL_COURIER_BOLD_ITALIC", "Enumerations_8H.html#a812b67c693f4809c778d39d77d15bb90", null ],
     [ "FL_COURIER_ITALIC", "Enumerations_8H.html#afc9d9ab48f1f9ff634c30fd2af4bb8ad", null ],
-    [ "FL_CYAN", "Enumerations_8H.html#a477aefad449ce8753aec45df51e7c896", null ],
-    [ "FL_DARK1", "Enumerations_8H.html#a2b6668e03d46f67a3ebeb6fc4713de4a", null ],
-    [ "FL_DARK2", "Enumerations_8H.html#ac11e9d182f35ff5fb029a0a28d12d919", null ],
-    [ "FL_DARK3", "Enumerations_8H.html#ad723ee5e7504ff3c0f07dbe34e894b9f", null ],
-    [ "FL_DARK_BLUE", "Enumerations_8H.html#a963656bd3d000130e87dee9caf88fa79", null ],
-    [ "FL_DARK_CYAN", "Enumerations_8H.html#a511dfe6574e00219227f624004d90cf7", null ],
-    [ "FL_DARK_GREEN", "Enumerations_8H.html#ae7d6f383011a292ae5c3f4973c4f8af6", null ],
-    [ "FL_DARK_MAGENTA", "Enumerations_8H.html#a9342461dac15e3237bd33b3246599b28", null ],
-    [ "FL_DARK_RED", "Enumerations_8H.html#a92460685e0e9d4709439cb5b43d28bff", null ],
-    [ "FL_DARK_YELLOW", "Enumerations_8H.html#a76a49382967c90b30ef2af300665fbe3", null ],
     [ "FL_FOREGROUND_COLOR", "Enumerations_8H.html#a8c67b74501f259f9bcfbf55415cfc162", null ],
     [ "FL_FREE_FONT", "Enumerations_8H.html#abdd37d3dbabf724c9bb0438916a6db2f", null ],
-    [ "FL_GRAY0", "Enumerations_8H.html#a8ef3d23aaa32b3038315aebdb8cb3fe0", null ],
-    [ "FL_GREEN", "Enumerations_8H.html#aed4198cc557c77e6a3a0d2ab243caf8f", null ],
     [ "FL_HELVETICA", "Enumerations_8H.html#a74d2c443f7ab53a6ce5d4ca0c7461bc9", null ],
     [ "FL_HELVETICA_BOLD", "Enumerations_8H.html#ae52b5d98292bf142ea1c7468d7d732cd", null ],
     [ "FL_HELVETICA_BOLD_ITALIC", "Enumerations_8H.html#a925bd586f4c991776b48827818c16707", null ],
     [ "FL_HELVETICA_ITALIC", "Enumerations_8H.html#a384a459d931aaf8140cd84034a5887dd", null ],
     [ "FL_INACTIVE_COLOR", "Enumerations_8H.html#a6501a998c459a5a117784f8c95a83a41", null ],
     [ "FL_ITALIC", "Enumerations_8H.html#abdc8e2cce930b923594df50760299776", null ],
-    [ "FL_LIGHT1", "Enumerations_8H.html#ab3a99b5be2f1cd0bd5d4b0bd723d1d31", null ],
-    [ "FL_LIGHT2", "Enumerations_8H.html#a186273e1025db07389a99cf29ac81493", null ],
-    [ "FL_LIGHT3", "Enumerations_8H.html#a1195306dc5887618e4ddea48c14da4ef", null ],
-    [ "FL_MAGENTA", "Enumerations_8H.html#a10c1bb0d1e91fee355084dcdebb4bf96", null ],
     [ "FL_NORMAL_SIZE", "Enumerations_8H.html#a200c616eb9f1a5d32a0b79847cef8cc8", null ],
-    [ "FL_RED", "Enumerations_8H.html#a3bba4191a4612c60d9b8a354815a800b", null ],
     [ "FL_SCREEN", "Enumerations_8H.html#a54136abc1d834eea22975288d5393ebe", null ],
     [ "FL_SCREEN_BOLD", "Enumerations_8H.html#abcd5288ae4c97da3a85ee095cafb44e0", null ],
     [ "FL_SELECTION_COLOR", "Enumerations_8H.html#a331e6d52a8f08e7d9bafd9cc8341cd9f", null ],
@@ -393,7 +279,5 @@ var Enumerations_8H =
     [ "FL_TIMES_BOLD", "Enumerations_8H.html#a41f70582714a3bd83fa3a32fb14b239f", null ],
     [ "FL_TIMES_BOLD_ITALIC", "Enumerations_8H.html#a1315245575ff4617c3dbee5b42649212", null ],
     [ "FL_TIMES_ITALIC", "Enumerations_8H.html#a881c8b4f190bccdf48d2df42ca921586", null ],
-    [ "FL_WHITE", "Enumerations_8H.html#ac1600c6c32be996f90f133cdc4135292", null ],
-    [ "FL_YELLOW", "Enumerations_8H.html#a22718da4ee9f26f647d93720a4927c77", null ],
     [ "FL_ZAPF_DINGBATS", "Enumerations_8H.html#a30b0e07f3e71e9942b7e30ebfcc73d37", null ]
 ];
\ No newline at end of file
